@@ -207,7 +207,7 @@ valtype specialBiKpBaB(
   indtype &Xsize = Nitem;
   // indtype lenCap = Xsize + 2; // lenCap is a infinity actually. Dummy.
   // vec<kpEle<double, int> > Xcontain(Xsize + 2);
-  Xcontain.resize(Xsize + 2); // Just for formality. Reallocation will never happen.
+  Xcontain.resize(Xsize + 3); // Just for formality. Reallocation will never happen.
   kpEle<valtype, indtype> *X = &Xcontain[0] + 1;
 
 
@@ -239,8 +239,20 @@ valtype specialBiKpBaB(
     // ================================ transform to maximum problem
     cap = X[Xsize - 1].accWeight - cap;
     // ================================
+    // X[Xsize].accWeight = X[Xsize - 1].accWeight + (cap + 1);
+    // X[Xsize].accValue = X[Xsize - 1].accValue + 0;
+
+
     X[Xsize].accWeight = X[Xsize - 1].accWeight + (cap + 1);
-    X[Xsize].accValue = X[Xsize - 1].accValue + 0;
+    X[Xsize].valuePerWeight = X[Xsize - 1].valuePerWeight / 2;
+    X[Xsize].accValue = X[Xsize - 1].accValue + X[Xsize].valuePerWeight * (cap + 1);
+    X[Xsize].minWeightAfter = cap + 2;
+
+
+    X[Xsize + 1].accWeight = X[Xsize].accWeight + (cap + 2);
+    X[Xsize + 1].valuePerWeight = X[Xsize].valuePerWeight / 2;
+    X[Xsize + 1].accValue = X[Xsize].accValue + X[Xsize + 1].valuePerWeight * (cap + 2);
+    X[Xsize + 1].minWeightAfter = cap + 3;
 
 
     X[Xsize - 1].minWeightAfter = cap + 1;
@@ -254,7 +266,7 @@ valtype specialBiKpBaB(
 
   // no time constraint.
   valtype penalty = X[Xsize - 1].accValue - bkp<valtype, indtype, fmove, false> (
-    X, Xsize, cap, Xsize + 2, stay, current, std::numeric_limits<double>::max());
+    X, Xsize, cap, Xsize, stay, current, std::numeric_limits<double>::max());
   // lenCap is infinite but is set to Xsize + 2.;
 
 
@@ -473,7 +485,7 @@ valtype gapBabStageI(vec<signed char> &currentSolution, vec<signed char> &Bconta
 
   // Auxiliary containers.
   // maxCore = std::min<int> (maxCore, Nagent);
-  vec<kpEle<valtype, indtype> > Xcontain(Ntask + 2); // aux
+  vec<kpEle<valtype, indtype> > Xcontain(Ntask + 3); // aux
   vec<valtype> valuePerWeight(Ntask);
   vec<indtype> unitValOrder(Ntask); // aux
   vec<indtype> current(Ntask); // aux
@@ -807,7 +819,7 @@ struct gapOBJ
     stay.resize(Nagent, vec<indtype>(Ntask));
     budgetExceedance.resize(Nagent);
     T.reserve(INT(Nagent) * Ntask);
-    Xcontain.reserve(Ntask + 2); // aux
+    Xcontain.reserve(Ntask + 3); // aux
     valuePerWeight.reserve(Ntask);
     unitValOrder.reserve(Ntask); // aux
     current.reserve(Ntask); // aux
@@ -1384,5 +1396,6 @@ List auxGAPbbMulthreadNodes(
 
 
 
+
 
 
